@@ -1,7 +1,7 @@
 from datetime import datetime, timedelta
 
 
-def format_date_epias_hour(date: str | datetime):
+def format_date_epias_hour(date: str | datetime, transform: str | None = None):
     """
     Desired format "2023-01-01T00:00:00+03:00"
     """
@@ -14,7 +14,17 @@ def format_date_epias_hour(date: str | datetime):
 
 
 def preprocess_parameter(key, value):
-    if key in ["start_date", "end_date", "date_time", "period"]:
+    if key in [
+        "start_date",
+        "end_date",
+        "date",
+        "period",
+        "se_date",
+        "period_start_date",
+        "period_end_date",
+        "version_start_date",
+        "version_end_date",
+    ]:
         value = format_date_epias_hour(value)
 
     elif key in ["region"]:
@@ -28,6 +38,10 @@ def preprocess_parameter(key, value):
         if value not in ["MCP", "SMP"]:
             raise Exception("Price type must be either MCP or SMP")
 
+    elif key in ["point_type"]:
+        if value not in ["INPUT", "OUTPUT"]:
+            raise Exception("Point type must be either INPUT or OUTPUT")
+
     elif key in ["intl_direction"]:
         # value = "TRGR" if value is None else value
         val_list = ["TRGR", "GRTR", "TRBG", "BGTR"]
@@ -45,4 +59,9 @@ def preprocess_parameter(key, value):
                 "Order type must be either UP_REGULATION, DOWN_REGULATION or BOTH_REGULATIONS"
             )
 
+    elif key in ["load_type"]:
+        value = "Baz" if value is None else value
+        if value not in ["Baz", "Puant", "Puant Dışı"]:
+            raise Exception("Load type must be either Baz, Puant or Puant Dışı")
+
     return value
